<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>FileControl</name>
    <message>
        <location filename="../src/filecontrol.cpp" line="781"/>
        <source>Fullscreen</source>
        <translation>Fullscreen</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="785"/>
        <source>Exit fullscreen</source>
        <translation>Exit fullscreen</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="789"/>
        <source>Extract text</source>
        <translation>Extract text</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="793"/>
        <source>Slide show</source>
        <translation>Slide show</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="797"/>
        <source>Rename</source>
        <translation>Rename</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="801"/>
        <location filename="../src/filecontrol.cpp" line="893"/>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="805"/>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="809"/>
        <source>Rotate clockwise</source>
        <translation>Rotate clockwise</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="813"/>
        <source>Rotate counterclockwise</source>
        <translation>Rotate counterclockwise</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="817"/>
        <source>Set as wallpaper</source>
        <translation>Set as wallpaper</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="821"/>
        <source>Display in file manager</source>
        <translation>Display in file manager</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="825"/>
        <source>Image info</source>
        <translation>Image info</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="829"/>
        <source>Previous</source>
        <translation>Previous</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="833"/>
        <source>Next</source>
        <translation>Next</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="837"/>
        <source>Zoom in</source>
        <translation>Zoom in</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="841"/>
        <source>Zoom out</source>
        <translation>Zoom out</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="845"/>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="849"/>
        <source>Print</source>
        <translation>Print</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="873"/>
        <source>Image Viewing</source>
        <translation>Image Viewing</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="877"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="881"/>
        <source>Display shortcuts</source>
        <translation>Display shortcuts</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="889"/>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="897"/>
        <source>Select all</source>
        <translation>Select all</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="905"/>
        <source>Live Text</source>
        <translation>Live Text</translation>
    </message>
</context>
<context>
    <name>InformationDialog</name>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="74"/>
        <source>Basic info</source>
        <translation>Basic info</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="98"/>
        <source>Size</source>
        <translation>Size</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="124"/>
        <source>Date captured</source>
        <translation>Date captured</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="131"/>
        <source>Date modified</source>
        <translation>Date modified</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="141"/>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="154"/>
        <source>Aperture</source>
        <translation>Aperture</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="162"/>
        <source>Exposure program</source>
        <translation>Exposure program</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="169"/>
        <source>Focal length</source>
        <translation>Focal length</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="175"/>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="182"/>
        <source>Exposure mode</source>
        <translation>Exposure mode</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="188"/>
        <source>Exposure time</source>
        <translation>Exposure time</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="194"/>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="201"/>
        <source>Flash compensation</source>
        <translation>Flash compensation</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="214"/>
        <source>Colorspace</source>
        <translation>Colorspace</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="221"/>
        <source>Metering mode</source>
        <translation>Metering mode</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="228"/>
        <source>White balance</source>
        <translation>White balance</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="246"/>
        <source>Lens model</source>
        <translation>Lens model</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="87"/>
        <source>File name</source>
        <translation>File name</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="105"/>
        <source>Dimensions</source>
        <translation>Dimensions</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="112"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="207"/>
        <source>Max aperture</source>
        <translation>Max aperture</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="239"/>
        <source>Device model</source>
        <translation>Device model</translation>
    </message>
</context>
<context>
    <name>LiveTextWidget</name>
    <message>
        <location filename="../qml/LiveText/LiveTextWidget.qml" line="155"/>
        <source>Copy (Ctrl+C)</source>
        <translation>Copy (Ctrl+C)</translation>
    </message>
    <message>
        <location filename="../qml/LiveText/LiveTextWidget.qml" line="172"/>
        <source>Select all (Ctrl+A)</source>
        <translation>Select all (Ctrl+A)</translation>
    </message>
</context>
<context>
    <name>MainStack</name>
    <message>
        <location filename="../qml/MainStack.qml" line="129"/>
        <source>Select pictures</source>
        <translation type="unfinished">Select pictures</translation>
    </message>
</context>
<context>
    <name>NonexistImageDelegate</name>
    <message>
        <location filename="../qml/ImageDelegate/NonexistImageDelegate.qml" line="43"/>
        <source>Image file not found</source>
        <translation type="unfinished">Image file not found</translation>
    </message>
</context>
<context>
    <name>OpenImageWidget</name>
    <message>
        <location filename="../qml/OpenImageWidget.qml" line="35"/>
        <source>Open Image</source>
        <translation>Open Image</translation>
    </message>
</context>
<context>
    <name>PropertyActionItemDelegate</name>
    <message>
        <location filename="../qml/InformationDialog/PropertyActionItemDelegate.qml" line="95"/>
        <source>The file already exists, please use another name</source>
        <translation>The file already exists, please use another name</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>Image Viewer</source>
        <translation>Image Viewer</translation>
    </message>
    <message>
        <location filename="../src/unionimage/unionimage_global.h" line="102"/>
        <source>day</source>
        <translation>day</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Image Viewer is an image viewing tool with fashion interface and smooth performance.</translation>
    </message>
</context>
<context>
    <name>ReName</name>
    <message>
        <location filename="../qml/ReName.qml" line="70"/>
        <source>Input a new name</source>
        <translation>Input a new name</translation>
    </message>
    <message>
        <location filename="../qml/ReName.qml" line="85"/>
        <source>The file already exists, please use another name</source>
        <translation>The file already exists, please use another name</translation>
    </message>
    <message>
        <location filename="../qml/ReName.qml" line="141"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../qml/ReName.qml" line="123"/>
        <source>Confirm</source>
        <translation>Confirm</translation>
    </message>
</context>
<context>
    <name>RemoveDialog</name>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="71"/>
        <source>Cannot move &quot;%1&quot; to the trash. Do you want to permanently delete it?</source>
        <translation>Cannot move &quot;%1&quot; to the trash. Do you want to permanently delete it?</translation>
    </message>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="89"/>
        <source>This action cannot be undone</source>
        <translation>This action cannot be undone</translation>
    </message>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="101"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="111"/>
        <source>Confirm</source>
        <translation>Confirm</translation>
    </message>
</context>
<context>
    <name>SliderShow</name>
    <message>
        <location filename="../qml/SliderShow.qml" line="155"/>
        <source>Previous</source>
        <translation>Previous</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="172"/>
        <location filename="../qml/SliderShow.qml" line="223"/>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="172"/>
        <location filename="../qml/SliderShow.qml" line="223"/>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="188"/>
        <source>Next</source>
        <translation>Next</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="203"/>
        <location filename="../qml/SliderShow.qml" line="244"/>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="173"/>
        <source>Next</source>
        <translation>Next</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="148"/>
        <source>Previous</source>
        <translation>Previous</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="209"/>
        <source>Original size</source>
        <translation>Original size</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="227"/>
        <source>Fit to window</source>
        <translation>Fit to window</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="244"/>
        <source>Rotate</source>
        <translation>Rotate</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="517"/>
        <source>Extract text</source>
        <translation>Extract text</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="536"/>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
</context>
<context>
    <name>ViewRightMenu</name>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="38"/>
        <source>Fullscreen</source>
        <translation>Fullscreen</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="38"/>
        <source>Exit fullscreen</source>
        <translation>Exit fullscreen</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="57"/>
        <source>Print</source>
        <translation>Print</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="76"/>
        <source>Extract text</source>
        <translation>Extract text</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="96"/>
        <source>Slide show</source>
        <translation>Slide show</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="117"/>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="137"/>
        <source>Rename</source>
        <translation>Rename</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="156"/>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="183"/>
        <source>Rotate clockwise</source>
        <translation>Rotate clockwise</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="203"/>
        <source>Rotate counterclockwise</source>
        <translation>Rotate counterclockwise</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="231"/>
        <source>Show navigation window</source>
        <translation>Show navigation window</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="231"/>
        <source>Hide navigation window</source>
        <translation>Hide navigation window</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="243"/>
        <source>Set as wallpaper</source>
        <translation>Set as wallpaper</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="263"/>
        <source>Display in file manager</source>
        <translation>Display in file manager</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="280"/>
        <source>Image info</source>
        <translation>Image info</translation>
    </message>
</context>
<context>
    <name>ViewTopTitle</name>
    <message>
        <location filename="../qml/ViewTopTitle.qml" line="189"/>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Image Viewer is an image viewing tool with fashion interface and smooth performance.</translation>
    </message>
    <message>
        <location filename="../qml/ViewTopTitle.qml" line="191"/>
        <source>Image Viewer</source>
        <translation>Image Viewer</translation>
    </message>
    <message>
        <location filename="../qml/ViewTopTitle.qml" line="167"/>
        <source>Open image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
